@@ -70,19 +70,27 @@ class dataFormatter:
         return features, samples
 
     def format_samples(self,
-                       key):
-        """return samples, either all, train, or test
+                       key,
+                       test_size=.5):
+        """formats samples and featurenames, either all, train, or test
         
         Args:
           key (str): 'all', 'train', or 'test', corresponding to sample type
+
+        Returns:
+            samples and featurenames: formatted
         """
-        if all(x is not None for x in [self.train_data,
+        
+        
+        if all(x is None for x in [self.train_data,
                                        self.test_data,
                                        self.samples]):
             raise ValueError("Split samples into test and train datasets or input samples first!")
         if key == 'train':
+            self.__train_test_split(1-test_size)
             samples = self.train_data
         elif key == 'test':
+            self.__train_test_split(test_size)
             samples = self.test_data
         elif key == 'all':
             samples = self.samples
@@ -103,7 +111,7 @@ class dataFormatter:
           vars ([str]): Mutable and immutable vars/features. Defaults to None.
 
         Returns:
-            [type]: [description]
+          features, vars: formatted to either upper or lower case
         """
         if lower:
             features = [x.lower() for x in self.features[key]]
@@ -123,18 +131,21 @@ class dataFormatter:
         """read in vars from file and set mutable, immutable
 
         Args:
-            lower (bool): Whether to set variables to lowercase (True) or not (False)
-            IMMUTABLE (book): IMMUTABLE if True, MUTABLE otherwise
-            FILE (str, optional): file with vars in singular column. Defaults to None.
-            LIST ([str], optional): 1D array of vars. Defaults to None.
+          lower (bool): Whether to set variables to lowercase (True) or not (False)
+          IMMUTABLE (book): IMMUTABLE if True, MUTABLE otherwise
+          FILE (str, optional): file with vars in singular column. Defaults to None.
+          LIST ([str], optional): 1D array of vars. Defaults to None.
+          
+        Returns:
+          mutable vars, immutable vars: list
         """
         if IMMUTABLE:
             immutable_vars = np.array(LIST)
             if FILE is not None:
                 immutable_vars = pd.read_csv(FILE,index_col=0).transpose()
             #assert_array_dimension(immutable_vars, 1)
-            features, immutable_vars = self.__set_varcase(immutable_vars,
-                                                          lower)
+            features, immutable_vars = self.__set_varcase(lower,
+                                                          vars=immutable_vars)
             mutable_vars = [x for x in features
                             if x not in immutable_vars]
             immutable_vars = [x for x in immutable_vars
@@ -146,8 +157,8 @@ class dataFormatter:
             if FILE is not None:
                 mutable_vars = pd.read_csv(FILE,index_col=0).transpose()
             #assert_array_dimension(mutable_vars, 1)
-            features, mutable_vars = self.__set_varcase(mutable_vars,
-                                                        lower)
+            features, mutable_vars = self.__set_varcase(lower,
+                                                        vars=mutable_vars)
             immutable_vars = [x for x in features
                               if x not in mutable_vars]
             mutable_vars = [x for x in mutable_vars
@@ -168,10 +179,13 @@ class dataFormatter:
         """set variables to be mutable or immutable
 
         Args:
-            immutable_list (list)): 1D array of immutable variables. Defaults to None.
-            IMMUTABLE_FILE (str, optional): file with immutable vars in singular column. Defaults to None.
-            mutable_list (list, optional): 1D array of immutable variables. Defaults to None.
-            MUTABLE_FILE (str, optional): file with mutable vars in singular column. Defaults to None.
+          immutable_list (list)): 1D array of immutable variables. Defaults to None.
+          IMMUTABLE_FILE (str, optional): file with immutable vars in singular column. Defaults to None.
+          mutable_list (list, optional): 1D array of immutable variables. Defaults to None.
+          MUTABLE_FILE (str, optional): file with mutable vars in singular column. Defaults to None.
+          
+        Returns:
+          mutable_vars, immutable_vars: list
         """
         list_None = assert_None([immutable_list,mutable_list], raise_error=False)
         file_None = assert_None([IMMUTABLE_FILE,MUTABLE_FILE], raise_error=False)
@@ -185,20 +199,20 @@ class dataFormatter:
             raise ValueError("Too many inputs! Only one argument needed")
         else:
             if IMMUTABLE_FILE is not None:
-                mutable_vars, immutable_vars = self.__interpretvars_fromfile(IMMUTABLE=True,
-                                                                             FILE=IMMUTABLE_FILE,
-                                                                             lower=lower)
+                mutable_vars, immutable_vars = self.__interpretvars(lower,
+                                                                    IMMUTABLE=True,
+                                                                    FILE=IMMUTABLE_FILE)
             elif MUTABLE_FILE is not None:
-                mutable_vars, immutable_vars = self.__interpretvars_fromfile(IMMUTABLE=False,
-                                                                             FILE=MUTABLE_FILE,
-                                                                             lower=lower)
+                mutable_vars, immutable_vars = self.__interpretvars(lower,
+                                                                    IMMUTABLE=False,
+                                                                    FILE=MUTABLE_FILE)
             elif immutable_list is not None:
-                mutable_vars, immutable_vars = self.__interpretvars_fromfile(IMMUTABLE=True,
-                                                                             LIST=immutable_list,
-                                                                             lower=lower)
+                mutable_vars, immutable_vars = self.__interpretvars(lower,
+                                                                    IMMUTABLE=True,
+                                                                    LIST=immutable_list)
             elif mutable_list is not None:
-                mutable_vars, immutable_vars = self.__interpretvars_fromfile(IMMUTABLE=False,
-                                                                             LIST=mutable_list,
-                                                                             lower=lower)
+                mutable_vars, immutable_vars = self.__interpretvars(lower,
+                                                                    IMMUTABLE=False,
+                                                                    LIST=mutable_list)
         self.mutable_vars, self.immutable_vars = mutable_vars, immutable_vars
         return mutable_vars, immutable_vars            
\ No newline at end of file
